@@ -1,5 +1,5 @@
 """
-x, y = material_engineering_QBD.read_sheet("
+x, y = material_engineering_QBD.read__sheet("
 AlGaAs 2A
 AsSb 4 nm
 GaInAs 8um
