@@ -232,13 +232,13 @@ def profile__plain(thicknesses, values):
     fence = [values[0]]
 
     for i in range(0,len(thicknesses) - 1):
-        ground.append(thicknesses[i])
+        ground.append(thicknesses[i] + ground[i * 2])
         fence.append(values[i])
 
-        ground.append(thicknesses[i])
+        ground.append(thicknesses[i] + ground[i * 2])
         fence.append(values[i + 1])
 
-    ground.append(thicknesses[-1])
+    ground.append(thicknesses[-1] + ground[-1])
     fence.append(values[-1])
 
     return ground, fence
